@@ -1,10 +1,10 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: authenticate
-version: 1.3.3.1
-id: authenticate-1.3.3.1-8e74591c5ee8d164fe0e2c4ea7f09e6c
-key: authe_Eolxs8WWZdL5HmE7MQHxvb
-license: MIT
+version: 1.3.3
+id: authenticate-1.3.3-e1786589aa33ebec7643f5494d2d4c58
+key: authe_F6xW5EBe6TgIOW0ZXVy6U2
+license: BSD3
 maintainer: Michael Snoyman <michael@snoyman.com>
 stability: Stable
 homepage: http://github.com/yesodweb/authenticate
@@ -20,29 +20,29 @@ exposed-modules:
 hidden-modules: Web.Authenticate.Internal OpenId2.Discovery
                 OpenId2.Normalization OpenId2.Types OpenId2.XRDS
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3.1
-data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3.1
-hs-libraries: HSauthenticate-1.3.3.1-Eolxs8WWZdL5HmE7MQHxvb
+import-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
+library-dirs: /usr/lib/ghc-7.10.3/site-local/authenticate-1.3.3
+data-dir: /usr/share/arm-linux-ghc-7.10.3/authenticate-1.3.3
+hs-libraries: HSauthenticate-1.3.3-F6xW5EBe6TgIOW0ZXVy6U2
 depends:
-    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
-    attoparsec-0.13.0.2-669cbb29a91e49834657a781d3adc2de
+    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
+    attoparsec-0.13.0.1-cc18275e376dae94cc21e54b8b072afd
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
+    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
-    conduit-1.2.6.6-d359386885a03b60281b91c4e140d8f4
+    case-insensitive-1.2.0.5-6669cd7a393ccedc4f66c0a01b6f0e2f
+    conduit-1.2.6.1-20c379c1e33e978c5d5c8f5ef78dd0c3
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    http-conduit-2.1.10.1-9bcd28b714a9db44a394bc84b9d644e0
-    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
-    monad-control-1.0.1.0-0cce93e14e6c79e66d2dc881e1ab9f6e
-    network-uri-2.6.1.0-522aa8cc2805dab5af7064f70c4a777d
-    resourcet-1.1.7.4-51f149abafdcf0369a30d929df00de54
-    tagstream-conduit-0.5.5.3-034cc2b60823e9366fbb547594b8242d
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
+    http-conduit-2.1.8-e2c4d8f7b8297fdf1ac5b7f32d06d5dd
+    http-types-0.9-d392878af9c5e1b1993961dc71a9e177
+    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
+    network-uri-2.6.0.3-27316eb865f3b3562ae77903534d67a4
+    resourcet-1.1.7.1-34b9e931a3d19e984bea5de562a18bbd
+    tagstream-conduit-0.5.5.3-ee2c4f50b9808fab97ea27c2a34b3894
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
-    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
+    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
+    xml-conduit-1.3.3.1-40ad40c80af811edb9755c807c4ab5cc
 haddock-interfaces: /usr/share/doc/haskell-authenticate/html/authenticate.haddock
 haddock-html: /usr/share/doc/haskell-authenticate/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
